"use strict";

require("core-js/modules/es.symbol");

require("core-js/modules/es.array.concat");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.flat-map");

require("core-js/modules/es.array.for-each");

require("core-js/modules/es.array.unscopables.flat-map");

require("core-js/modules/es.object.define-properties");

require("core-js/modules/es.object.define-property");

require("core-js/modules/es.object.get-own-property-descriptor");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/es.object.keys");

require("core-js/modules/es.string.repeat");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/** get diagonal repeat lines: looks something like
 *   /             \
    |.             .|
    |.  A m  Gm7   .|
     \             /
*/
var getRepeatLines = function getRepeatLines(dims, type) {
  //x and y determine the diagonal line's length
  var y = 5;
  var x = 7;
  var drawX = type === "backward" ? -x : x;
  var moveX = type === "backward" ? dims.xEnd : dims.x;
  return ["M" + moveX + " " + dims.y + " l " + drawX + " " + -y, "M" + moveX + " " + dims.yEnd + " l " + drawX + " " + y];
};
/* get the points in the repetition
 *  |:  A m7   |  Gm7  :|
 * */


var getRepetitionCircles = function getRepetitionCircles(bars, barView) {
  var yDistance = 4; // from y center of bar to point (either point above or below)

  var xDistance = 4; // distance from bar to points

  var getY = function getY(y, type) {
    var fDist = type === "up" ? -yDistance : yDistance;
    return y + barView.bar.height / 2 + fDist;
  };

  var circle = {
    r: 1,
    stroke: "black"
  };

  var getCircles = function getCircles(bar, barView) {
    var x = bar.repeat === "forward" ? bar.dimensions.x + xDistance : bar.dimensions.x + barView.bar.width - xDistance;
    var y1 = getY(bar.dimensions.y, "up");
    var y2 = getY(bar.dimensions.y, "down");

    var circle1 = _objectSpread({}, circle, {}, {
      cx: x,
      cy: y1
    });

    var circle2 = _objectSpread({}, circle, {}, {
      cx: x,
      cy: y2
    });

    return [circle1, circle2];
  };

  return bars.filter(function (bar) {
    return !!bar.repeat;
  }).flatMap(function (bar) {
    return getCircles(bar, barView);
  });
};

var getBarLines = function getBarLines(bars, barView) {
  if (!barView.bar || barView.bar.width === undefined || barView.bar.height === undefined || barView.bar.repetitionLineSpace === undefined) throw new TypeError("barView arguments needed: bar.width, bar.height and bar.repetitionLineSpace");
  var barLines = bars.flatMap(function (bar) {
    var dims = {
      x: bar.dimensions.x,
      y: bar.dimensions.y,
      xEnd: bar.dimensions.x + barView.bar.width,
      yEnd: bar.dimensions.y + barView.bar.height
    };
    var line = ["M" + dims.xEnd + " " + dims.y + " l 0 " + barView.bar.height];
    if (bar.endSection) line.push("m" + (dims.xEnd - barView.bar.repetitionLineSpace) + " " + dims.y + " l 0 " + barView.bar.height);

    if (bar.repeat) {
      if (bar.repeat === "forward") {
        line.push("m" + dims.x + " " + dims.y + " l 0 " + barView.bar.height);
      }

      line = line.concat(getRepeatLines(dims, bar.repeat));
    }

    return line;
  });
  return {
    paths: barLines,
    circles: getRepetitionCircles(bars, barView)
  };
};

var _default = getBarLines;
exports["default"] = _default;